@@ -25,7 +25,7 @@
 #ifndef EQUATIONEDITOR_H
 #define EQUATIONEDITOR_H
 
-#include <KDialog>
+#include <QDialog>
 
 class EquationEdit;
 class EquationEditorWidget;
@@ -36,12 +36,12 @@ class EquationEditorWidget;
  * special characters.
  * \author David Saxton
  */
-class EquationEditor : public KDialog
+class EquationEditor : public QDialog
 {
 	Q_OBJECT
 			
 	public:
-		EquationEditor(QWidget* parent);
+		explicit EquationEditor(QWidget* parent);
 		
 		/**
 		 * The equation's text, e.g. "f(x) = x^2".
