@@ -22,7 +22,7 @@
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
-/** @file MainDlg.h
+/** @file maindlg.h
  * @brief Contains the main window class MainDlg. */
 
 #ifndef MainDlg_included
@@ -31,6 +31,7 @@
 // Qt includes
 #include <QDomDocument>
 #include <QMenu>
+#include <QPrinter>
 #include <QStack>
 #include <QStandardPaths>
 
@@ -47,6 +48,7 @@
 #include "coordsconfigdialog.h"
 #include "view.h"
 #include "kmplotio.h"
+#include "kprinterdlg.h"
 
 class BrowserExtension;
 class Calculator;
@@ -134,6 +136,8 @@ public slots:
 	void slotSaveas();
 	///Print the current plot
 	void slotPrint();
+	/// For calling print preview functionality
+	void slotPrintPreview();
 	///Export the current plot as a png, svg or bmp picture
 	void slotExport();
 	///Implement the Configure KmPlot dialog
@@ -151,11 +155,13 @@ public slots:
 private:
 	/// Settings the standard and non standard actions of the application.
 	void setupActions();
-	/// Called when a file is opened. The filename is is m_url
+	/// Sets the printer options and draw the plot with the current options.
+	void setupPrinter(KPrinterDlg *printDialog, QPrinter *printer);
+	/// Called when a file is opened. The filename is m_url
 	bool openFile() Q_DECL_OVERRIDE;
 
-
-    bool saveFile() Q_DECL_OVERRIDE;
+	/// Called when a file is saved. The filename is m_url
+	bool saveFile() Q_DECL_OVERRIDE;
 
 	///The Recent Files action
 	KRecentFilesAction * m_recentFiles;
@@ -215,6 +221,9 @@ private:
 	/// A pointer to ourselves
 	static MainDlg * m_self;
 
+	/// Root value for copying into clipboard
+	double m_rootValue;
+
 protected slots:
 	/**
 	* When you click on a File->Open Recent file, it'll open
